@@ -3,8 +3,6 @@
 
 #include "consolelog.h"
 
-#include <QFileInfo>
-
 ConsoleLog::ConsoleLog(QObject *parent)
     : QAbstractListModel(parent)
 {
@@ -45,3 +43,5 @@ void ConsoleLog::addEntry(const QString &output, EntryType type)
     m_logEntries.push_back({output, type});
     endInsertRows();
 }
+
+#include "moc_consolelog.cpp"
